==> connector-service-1.0.7-20210918.094424-6-sources.jar: com/bizvane/connectorservice/entity/common/CouponBindRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.ToString;

/**
 * @Author: liuying@bizvane.cn
 * @Date: 2019/3/12 10:23
 * @Version 1.0
 */
@Data
@ToString
public class CouponBindRequestVO extends BaseModel {

    @ApiModelProperty(
            value = "券号",
            name = "couponCode",
            required = false,
            example = ""
    )
    private String couponCode;

    private String erpCouponDefinitionCode;
    
    @ApiModelProperty(
            value = "会员线下id",
            name = "erpId",
            required = false,
            example = ""
    )
    private String erpId;

    @ApiModelProperty(
            value = "会员线下卡号",
            name = "offlineCardNo",
            required = false,
            example = ""
    )
    private String offlineCardNo;

    @ApiModelProperty(
            value = "券定义号",
            name = "batchCode",
            required = false,
            example = ""
    )
    private String batchCode;

    /**
     * 是否补发(1,是 ,0,否)
     */
    private Integer isReissue;

    public Integer getIsReissue() {
        return isReissue;
    }

    public void setIsReissue(Integer isReissue) {
        this.isReissue = isReissue;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public String getBatchCode() {
        return batchCode;
    }

    public void setBatchCode(String batchCode) {
        this.batchCode = batchCode;
    }
}

==> connector-service-1.0.8-20210915.033420-4-sources.jar: com/bizvane/connectorservice/entity/common/CouponBindRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.ToString;

/**
 * @Author: liuying@bizvane.cn
 * @Date: 2019/3/12 10:23
 * @Version 1.0
 */
@Data
@ToString
public class CouponBindRequestVO extends BaseModel {

    @ApiModelProperty(
            value = "券号",
            name = "couponCode",
            required = false,
            example = ""
    )
    private String couponCode;

    private String erpCouponDefinitionCode;
    
    @ApiModelProperty(
            value = "会员线下id",
            name = "erpId",
            required = false,
            example = ""
    )
    private String erpId;

    @ApiModelProperty(
            value = "会员线下卡号",
            name = "offlineCardNo",
            required = false,
            example = ""
    )
    private String offlineCardNo;

    @ApiModelProperty(
            value = "券定义号",
            name = "batchCode",
            required = false,
            example = ""
    )
    private String batchCode;

    /**
     * 是否补发(1,是 ,0,否)
     */
    private Integer isReissue;

    @ApiModelProperty(
            value = "发券人",
            name = "createUserName",
            required = false,
            example = ""
    )
    private String sendCouponUserName;

    public Integer getIsReissue() {
        return isReissue;
    }

    public void setIsReissue(Integer isReissue) {
        this.isReissue = isReissue;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public String getBatchCode() {
        return batchCode;
    }

    public void setBatchCode(String batchCode) {
        this.batchCode = batchCode;
    }

    public String getSendCouponUserName() {
        return sendCouponUserName;
    }

    public void setSendCouponUserName(String sendCouponUserName) {
        this.sendCouponUserName = sendCouponUserName;
    }
}
